"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = MagnifyHint;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _amp = require("next/amp");

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styles = require("@material-ui/core/styles");

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _AddCircleOutline = _interopRequireDefault(require("@material-ui/icons/AddCircleOutline"));

var _clsx2 = _interopRequireDefault(require("clsx"));

var styles = function styles(theme) {
  return {
    root: {
      position: 'absolute',
      bottom: 30,
      display: 'flex',
      flexDirection: 'row',
      justifyContent: 'center',
      width: '100%'
    },
    wrap: {
      borderRadius: 25,
      backgroundColor: 'rgba(0, 0, 0, 0.3)',
      lineHeight: 14,
      padding: '5px 10px',
      display: 'flex',
      flexDirection: 'row',
      alignItems: 'center'
    },
    icon: {
      height: 16,
      width: 16,
      color: theme.palette.grey[300]
    },
    text: {
      marginLeft: 5,
      color: theme.palette.grey[300],
      position: 'relative',
      top: 1
    },
    over: {},
    zoomDisabled: {},
    expandDisabled: {
      // hide the whole component when:
      // - both zoom and expand are disabled
      // - expand is disabled and user is mobile
      '$zoomDisabled&': {
        display: 'none'
      },
      '@media (hover:none)': {
        display: 'none'
      }
    },
    zoomTextDesktop: {
      display: 'block',
      // hide zoom text when:
      // - hovering + expand is enabled
      // - zoom is disabled
      // - mobile user
      '$over:not($expandDisabled) &, $zoomDisabled &': {
        display: 'none'
      },
      '@media (hover:none)': {
        display: 'none'
      }
    },
    expandTextMobile: {
      display: 'none',
      '@media (hover:none)': {
        display: 'block'
      }
    },
    expandTextDesktop: {
      display: 'none',
      '$over:not($expandDisabled) &, $zoomDisabled &': {
        display: 'block',
        '@media (hover:none)': {
          display: 'none'
        }
      }
    }
  };
};

var useStyles = (0, _styles.makeStyles)(styles, {
  name: 'RSFMagnifyHint'
});

function MagnifyHint(_ref) {
  var _clsx;

  var zoomTextDesktop = _ref.zoomTextDesktop,
      expandTextMobile = _ref.expandTextMobile,
      expandTextDesktop = _ref.expandTextDesktop,
      over = _ref.over,
      className = _ref.className,
      disableZoom = _ref.disableZoom,
      disableExpand = _ref.disableExpand;
  var classes = useStyles();
  disableZoom = disableZoom || (0, _amp.useAmp)();
  return _react["default"].createElement("div", {
    className: (0, _clsx2["default"])(className, (_clsx = {}, (0, _defineProperty2["default"])(_clsx, classes.root, true), (0, _defineProperty2["default"])(_clsx, classes.over, over), (0, _defineProperty2["default"])(_clsx, classes.zoomDisabled, disableZoom), (0, _defineProperty2["default"])(_clsx, classes.expandDisabled, disableExpand), _clsx))
  }, _react["default"].createElement("div", {
    className: classes.wrap
  }, _react["default"].createElement(_AddCircleOutline["default"], {
    className: classes.icon,
    alt: "magnify-icon"
  }), _react["default"].createElement(_Typography["default"], {
    variant: "caption",
    className: (0, _clsx2["default"])(classes.text, classes.zoomTextDesktop)
  }, zoomTextDesktop), _react["default"].createElement(_Typography["default"], {
    variant: "caption",
    className: (0, _clsx2["default"])(classes.text, classes.expandTextMobile)
  }, expandTextMobile), _react["default"].createElement(_Typography["default"], {
    variant: "caption",
    className: (0, _clsx2["default"])(classes.text, classes.expandTextDesktop)
  }, expandTextDesktop)));
}

MagnifyHint.propTypes = {
  zoomTextDesktop: _propTypes["default"].string,
  expandTextMobile: _propTypes["default"].string,
  expandTextDesktop: _propTypes["default"].string,
  className: _propTypes["default"].string,
  open: _propTypes["default"].bool,
  disableZoom: _propTypes["default"].bool,
  disableExpand: _propTypes["default"].bool
};
MagnifyHint.defaultProps = {
  zoomTextDesktop: 'Hover to Zoom',
  expandTextMobile: 'Tap to Expand',
  expandTextDesktop: 'Click to Expand'
};
//# sourceMappingURL=MagnifyHint.js.map